@@ -28,6 +28,7 @@ from PIL import Image
 from .thermogram import FlyrThermogram
 from .palette_info import Palette
 from .picture_in_picture import PictureInPicture
+from .camera_metadata import CameraMetadata
 
 
 # Constants
@@ -76,7 +77,8 @@ def unpack(path_or_stream: Union[str, BinaryIO]) -> FlyrThermogram:
         stream = path_or_stream
         flir_app1_stream = extract_flir_app1(stream)
         flir_records = parse_flir_app1(flir_app1_stream)
-        thermogram = parse_thermal(flir_app1_stream, flir_records)
+        stream.seek(0)
+        thermogram = parse_thermal(flir_app1_stream, flir_records, stream)
 
         return thermogram
     else:
@@ -197,7 +199,9 @@ def parse_flir_chunk(
 
 
 def parse_thermal(
-    stream: BinaryIO, records: Dict[int, Tuple[int, int, int, int]]
+    thermal_stream: BinaryIO,
+    records: Dict[int, Tuple[int, int, int, int]],
+    file_stream: BinaryIO,
 ) -> FlyrThermogram:
     # FIXME Support formats other than subtype == PNG
     RECORD_IDX_RAW_DATA = 1
@@ -207,28 +211,30 @@ def parse_thermal(
     RECORD_IDX_PICTURE_IN_PICTURE_INFO = 42
 
     raw_data_md = records[RECORD_IDX_RAW_DATA]
-    width, height, raw_data = parse_raw_data(stream, raw_data_md)
+    width, height, raw_data = parse_raw_data(thermal_stream, raw_data_md)
 
     embedded_image = None
     try:
         embedded_image_md = records[RECORD_IDX_EMBEDDED_IMAGE]
-        _, _, embedded_image = parse_embedded_image(stream, embedded_image_md)
+        _, _, embedded_image = parse_embedded_image(thermal_stream, embedded_image_md)
     except:
         pass
 
     camera_info_md = records[RECORD_IDX_CAMERA_INFO]
-    camera_info = parse_camera_info(stream, camera_info_md)
+    camera_info = parse_camera_info(thermal_stream, camera_info_md)
 
     try:
         palette_info_md = records[RECORD_IDX_PALETTE_INFO]
-        palette_info: Optional[Palette] = parse_palette_info(stream, palette_info_md)
+        palette_info: Optional[Palette] = parse_palette_info(
+            thermal_stream, palette_info_md
+        )
     except:
         palette_info = None
 
     try:
         pip_info_md = records[RECORD_IDX_PICTURE_IN_PICTURE_INFO]
         pip_info: Optional[PictureInPicture] = parse_picture_in_picture_info(
-            stream, pip_info_md
+            thermal_stream, pip_info_md
         )
     except:
         pip_info = None
@@ -239,6 +245,7 @@ def parse_thermal(
         optical=embedded_image,
         palette=palette_info,
         picture_in_picture=pip_info,
+        metadata_camera=CameraMetadata(file_stream),
     )
     return thermogram
 
@@ -423,6 +430,9 @@ def parse_camera_info(
     atmospheric_trans_beta2 = stream.read(4)
     atmospheric_trans_x = stream.read(4)
 
+    cam_temp_range_max = stream.read(4)
+    cam_temp_range_min = stream.read(4)
+
     stream.seek(offset + 776)
     planck_o = stream.read(4)
     planck_r2 = stream.read(4)
@@ -459,6 +469,8 @@ def parse_camera_info(
         "raw_value_range_max": struct.unpack("H", raw_value_range_max)[0],
         "raw_value_median": struct.unpack("i", raw_value_median)[0],
         "raw_value_range": struct.unpack("i", raw_value_range)[0],
+        "camera_temperature_range_max": float_from_bytes(cam_temp_range_max),
+        "camera_temperature_range_min": float_from_bytes(cam_temp_range_min),
     }
 
     to_round = [
