@@ -26,7 +26,7 @@ from .turbo import turbo
 from .viridis import viridis
 
 
-palettes: Dict[str, List[List[int]]] = {
+palettes: Dict[str, List[Tuple[int, int, int]]] = {
     "cividis": cividis,
     "copper": copper,
     "gist_earth": gist_earth,
@@ -45,7 +45,8 @@ palettes: Dict[str, List[List[int]]] = {
 
 
 def map_colors(
-    thermal: Array[float, ..., ...], palette: str = "jet"
+    thermal: Array[float, ..., ...],
+    palette: Union[str, List[Tuple[int, int, int]]] = "jet",
 ) -> Array[np.uint8, ..., ..., 3]:
     """ Colors a normalized image array.
 
@@ -60,7 +61,10 @@ def map_colors(
             A 3D array with channels as its last dimension, containing integers
             between 0 and 255.
     """
-    colors = palettes[palette]
+    if isinstance(palette, list):
+        colors = palette
+    elif isinstance(palette, str):
+        colors = palettes[palette]
 
     colored = np.zeros(thermal.shape + (3,), dtype=np.uint8)
     num_colors = len(colors)
