@@ -15,6 +15,7 @@ import flyr.normalization as norm
 import flyr.palette_info as pal
 import flyr.picture_in_picture as pip
 import flyr.image_manipulation as manip
+import flyr.camera_metadata as cm
 
 
 class FlyrThermogram:
@@ -41,6 +42,7 @@ class FlyrThermogram:
     palette: Optional[pal.Palette]
     pip_info: Optional[pip.PictureInPicture]
     path: Optional[str]
+    camera_metadata: Optional[cm.CameraMetadata]
 
     def __init__(
         self,
@@ -51,6 +53,7 @@ class FlyrThermogram:
         picture_in_picture: Optional[pip.PictureInPicture] = None,
         path: Optional[str] = None,
         metadata_adjustments: Dict[str, Union[float, int]] = {},
+        metadata_camera: Optional[cm.CameraMetadata] = None,
     ):
         """ Initialize a new instance of this class. The raw thermal data and
             the accompanying metadata to correctly interpret this data are
@@ -83,6 +86,7 @@ class FlyrThermogram:
                 A dictionary with adjustments to the above dictionary. This
                 separation allows both using the original settings and
                 calculating temperatures with different physical parameters.
+            metadata_camera: Optional[cm.CameraMetadata]
 
             Returns
             -------
@@ -95,6 +99,7 @@ class FlyrThermogram:
         self.palette = palette
         self.pip_info = picture_in_picture
         self.path = path
+        self.camera_metadata = metadata_camera
 
     @property
     def kelvin(self) -> Array[np.float64, ..., ...]:
